# jQuery UI Explode Effect

## Overview

Explodes or implodes the element into/from many pieces.

### Dependencies

- Effects Core

### Example

- Demo
- View Source

Hides the element by exploding it into 9 pieces.

    $("div").click(function () {
          $(this).hide("explode", 1000);
    });

    <!DOCTYPE html>
    <html>
    <head>
      <link href="http://ajax.googleapis.com/ajax/libs/jqueryui/1.8/themes/base/jquery-ui.css" rel="stylesheet" type="text/css"/>
      <script src="http://ajax.googleapis.com/ajax/libs/jquery/1.4/jquery.min.js"></script>
      <script src="http://ajax.googleapis.com/ajax/libs/jqueryui/1.8/jquery-ui.min.js"></script>
      <style type="text/css">
      div { margin: 0px; width: 100px; height: 80px; background: green; border: 1px solid black; position: relative; }
    </style>

      <script>
      $(document).ready(function() {

    $("div").click(function () {
          $(this).hide("explode", 1000);
    });

      });
      </script>
    </head>
    <body style="font-size:62.5%;">
      <div></div>
    </body>
    </html>

- Demo
- View Source

Shows the element by imploding it from 16 pieces.

    $("div").click(function () {
          $(this).show("explode", { pieces: 16 }, 2000);
    });

    <!DOCTYPE html>
    <html>
    <head>
      <link href="http://ajax.googleapis.com/ajax/libs/jqueryui/1.8/themes/base/jquery-ui.css" rel="stylesheet" type="text/css"/>
      <script src="http://ajax.googleapis.com/ajax/libs/jquery/1.4/jquery.min.js"></script>
      <script src="http://ajax.googleapis.com/ajax/libs/jqueryui/1.8/jquery-ui.min.js"></script>

    <script src="http://dev.jquery.com/view/tags/ui/latest/ui/effects.core.js"></script>
    <script src="http://dev.jquery.com/view/tags/ui/latest/ui/effects.explode.js"></script>
    <style type="text/css">
      div { margin: 0px; width: 100px; height: 80px; background: green; border: 1px solid black; position: relative; }
    </style>

      <script>
      $(document).ready(function() {

    $("div").click(function () {
          $(this).show("explode", { pieces: 16 }, 2000);
    });

      });
      </script>
    </head>
    <body style="font-size:62.5%;">
      <div></div>
    </body>
    </html>

## Arguments

- ### mode

  Type:
    String

  The mode of the animation. Can be set to "show" or "hide".

- ### pieces

  Type:
    Integer
  Default:
    9

  Number of pieces to be exploded to/imploded from.